% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
%                4.3.2011      T. Roeder, Rohde & Schwarz
%
% *************************************************************************

session = 0;
Length  = 500;

% we run the following commands in a dummy loop that allows for
% an easier error handling
while( true )

    % locate and load the VXI-PnP driver DLL
    [Status, libname] = rs_nrpz_load_vxipnp();
    if( Status==0 ); 
        disp( 'Cannot load driver.' );
        break; 
    end;

    % open any available sensor
    %   Set the resource descriptor for the USB Power Sensor  
    %   '*' uses the first available sensor. It is also possible
    %   to provide the USB resources string here, using the format
    %   'USB::<vendorID>::<productID>::<serial number>'
    %   The vendor ID for R&S instruments is 0x0AAD
    %   The product ID depends on the sensor. See the driver documentation
    %   or Power Viewer Plus manual for details.
    [Status, session] = rs_nrpz_init( libname, '*' );
    if( Status==0 ); break; end;
    
    % Read sensor name, e.g. 'NRP-Z81'
    [Status, Name] = rs_nrpz_get_sensorname( libname, session );
    if( Status==0 ); break; end;
    disp( [ 'Sensor Type: ' Name ] );

    disp ('  ');
    disp ('=== MEASURE TRACE WITH NRP-Z SENSOR ===');

    Frequency     = 1e9;            % carrier frequency
    TraceTime     = 10e-3;          % total time for X axis

    % The sensor opened through rsnrpz_init() always uses channel 1.
    channel = 1;
    
    Status = rs_nrpz_setup_trace( libname, session, Frequency, 0.0, TraceTime ); 
    if( Status==0 ); break; end;

    % Run one single measurement and return the value.
    % 5000 = 5 sec timeout
    [Status, ResultArray] = rs_nrpz_read_buf_meas( libname, session, Length ); 
    if( Status==0 ); break; end;
    
    break
   
end

% Close sensor connection. It must be ensured that the sensor is closed
% at the end of the program !
%   It is possible to close rsnrpz_close() with 0 as the session number in
%   order to close all open sessions.
%   err = calllib( libname, 'rsnrpz_close', 0 );
if( session ~= 0 )
    rs_nrpz_close( libname, session ); 
end

if( Status~=0 )
    disp ([ 'Number of trace points read: ', num2str(Length) ]);

    % create X scale
    x = 0 : TraceTime/Length : TraceTime-TraceTime/Length;

    % Plot measurement result in linear scale
    subplot( 2, 1, 1 );
    plot( x, ResultArray .* 1e3 );
    title( 'Linear Scale Trace Data / mW' );

    % convert to log scale (dBm)
    ResultLog = 10 * log10( 10e-32 + abs(ResultArray) ) + 30;

    % plot measurement data in log scale
    subplot( 2, 1, 2 );
    plot( x, ResultLog );
    title('Log Scale Trace Data / dBm');
end

% **********************************************************************
% Unloading the library may cause problems ('unhandled exceptions in
% MATLAB.exe'). It is therefore suggested to leave this library loaded.
% Restarting the script detects the libray and it is not loaded again.
% unloadlibrary( 'rsnrpz_32' ) or unloadlibrary( 'rsnrpz_64' )

%clear;
disp (' ');
return;




