% function rs_nrpz_get_sensorname
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function reads the sensor name, e.g. 'NRP-Z81'
% @param  libname                     The name of the library.
% @param  session                     The session ID.
%%
% @return Name                        Sensor name
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status, Name] = rs_nrpz_get_sensorname( libname, session )  

    Status = 0;

    z = zeros( 1, 512, 'int8' );
    pReturnText   = libpointer( 'int8Ptr', z );

    % The sensor opened through rsnrpz_init() always uses channel 1.
    channel = 1;

    % Read sensor information
    pInfoType = libpointer( 'int8Ptr', [int8( 'Type' ) 0] );
    
    [err, DummyTxt, Name] = calllib( libname, 'rsnrpz_chan_info',...
                 session, channel, pInfoType, 512, pReturnText );
    if( err<0 )
        [dummy, ErrorText] = rs_nrpz_get_error( libname, session, err );
        disp( ErrorText );
        return;  
    end;
    
    Status = 1;
   
return;

