% function rs_nrpz_load_vxipnp 
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function loads the rsnrpz_32.dll or rsnrpz_64.dll VXI-PnP
% driver for use with the Rohde&Schwarz NRP-Zxx Power Sensors.
%%
% @return Libname                     The name of the library.
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status, Libname] = rs_nrpz_load_vxipnp( )  

    Status = 0;
    
    % get the path of the VXI PnP driver
    driverinfo = instrhwinfo( 'vxipnp' );
    path       = driverinfo.VXIPnPRootPath;

    % path = 'C:\Program Files\IVI Foundation\VISA\Win64';
    % path = 'C:\Program Files\IVI Foundation (x86)\VISA\WINNT';
    % path = 'C:\VXIPnP\WINNT';

    disp( [ 'Your reported VXI-PnP path is ' path ] );

    % get architecture win32, win64, ...
    archstr     = computer('arch');
    Libname     = 'rsnrpz_32';
    if ~isempty( strfind( archstr, '64') )
        disp( 'This is a 64-bit installation.' );
        Libname = 'rsnrpz_64';

        % There seems to be a bug where the path is not correctly
        % reported on Win64 systems
        if ~isempty( strfind( path, 'WINNT')) && ~exist( path )
            
            disp( 'Correcting VXI-PnP path for 64-Bit Installation' );
            path = strrep( path, 'WINNT', 'Win64' );
            
            % show the path
            disp( [ 'Using VXI-PnP root path: ' path ] );

        end
    end

    % Check if the path is there
    if ~exist( path )
       disp( 'The VXI-PnP root path does not exist.' ); 
       return;
    end

    % add these paths
    addpath( [ path '\Bin'] );
    addpath( [ path '\include'] );

    % Load the VXI-PnP library (.dll) for sensor access 
    % if it has not yet been loaded yet
    if ~libisloaded( Libname )
        loadlibrary( Libname, 'rsnrpz.h' );
    end

    % Optionally show all available functions or function details
    if 0
        libfunctions( Libname );
    end;

    if 0
        libfunctionsview( Libname );
    end;
    
    Status = 1;

return;

