% function rs_nrpz_read_buf_meas
% *************************************************************************
% 
% Copyright: (c) 2011 Rohde & Schwarz GmbH & CO KG.    All rights reserved.
%                Muehldorfstr. 15
%                D-81671 Munich
%
% *************************************************************************
% This function starts a measurement and waits for its completion.
%
% @param  libname                     The name of the library.
% @param  session                     The session ID.
% @param  points                      Number of samples to read.
%%
% @return Result                      Sensor reading
% @return Status                      Status = 0, error occured.
%                                     Status = 1, OK.
%**************************************************************************
function [Status, ResultArray] = rs_nrpz_read_buf_meas( libname, session, points )  

    Status = 0;

    % The sensor opened through rsnrpz_init() always uses channel 1.
    channel = 1;
    
    % Create pointer for length
    pLength       = libpointer( 'int32Ptr', 0 );

    % The buffer needs to be large enough for the points.
    z0 = zeros( 1, points );
    pMeasArray    = libpointer( 'doublePtr', z0 );   

    % Run one single measurement and return the value.
    % 5000 = 5 sec timeout
    [err, ResultArray, Length] = calllib( libname, 'rsnrpz_meass_readBufferMeasurement', ...
            session, channel, 5000, points, pMeasArray, pLength );
    
    if( err<0 )
        [dummy, ErrorText] = rs_nrpz_get_error( libname, session, err );
        disp( ErrorText );
        return;  
    end;
    
    Status = 1;
   
return;

